@@ -1,13 +1,11 @@
 #' @title Function to run generalized linear model (glm) across multiple
 #'   grouping variables.
 #' @name grouped_glm
-#' @aliases grouped_glm
 #' @author Indrajeet Patil
 #' @return A tibble dataframe with tidy results from linear model.
 #'
 #' @inheritParams grouped_lm
 #'
-#' @importFrom magrittr "%<>%"
 #' @importFrom broomExtra grouped_tidy grouped_glance grouped_augment
 #' @importFrom rlang !! enquos
 #'
@@ -44,7 +42,7 @@ grouped_glm <- function(data,
     # tidy results
     combined_df <- broomExtra::grouped_tidy(
       data = data,
-      grouping.vars = !!rlang::enquo(grouping.vars),
+      grouping.vars = {{ grouping.vars }},
       ..f = stats::glm,
       ...,
       tidy.args = tidy.args
@@ -52,8 +50,7 @@ grouped_glm <- function(data,
 
     # add a column with significance labels if p-values are present
     if ("p.value" %in% names(combined_df)) {
-      combined_df %<>%
-        signif_column(data = ., p = p.value)
+      combined_df %<>% signif_column(data = ., p = p.value)
     }
   }
 
@@ -61,7 +58,7 @@ grouped_glm <- function(data,
     # tidy results
     combined_df <- broomExtra::grouped_glance(
       data = data,
-      grouping.vars = !!rlang::enquo(grouping.vars),
+      grouping.vars = {{ grouping.vars }},
       ..f = stats::glm,
       ...
     )
@@ -71,7 +68,7 @@ grouped_glm <- function(data,
     # tidy results
     combined_df <- broomExtra::grouped_augment(
       data = data,
-      grouping.vars = !!rlang::enquo(grouping.vars),
+      grouping.vars = {{ grouping.vars }},
       ..f = stats::glm,
       ...,
       augment.args = augment.args
